#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-KkGzbqquK3FI3yCoiiOr4n
key:                  xmonad-dbus-0.1.0.2-KkGzbqquK3FI3yCoiiOr4n
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  9ab613ea2f51c8a10463007ba2d1a390
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-KkGzbqquK3FI3yCoiiOr4n
depends:              base-4.18.2.1 dbus-1.3.3-14zrP2ElPyi7I7UEc8EF80
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

